Getting Started
===============

This section covers how to install and set up the Hydro-Topo Features package for your own projects.

.. toctree::
   :maxdepth: 2

   installation
   quickstart
   configuration

Installation
-----------

.. include:: installation.rst

Quick Start
----------

.. include:: quickstart.rst

Configuration
-----------

.. include:: configuration.rst 